#include <torch/torch.h>
#include <torch/script.h>

#include <iostream>
#include <memory>

extern "C" {
 float** ANNpredict(float*** input) {   // const perché input all'interno non viene modificato 

  auto inputs = torch::from_blob(&input, {81897, 5, 8}, torch::kFloat);
  torch::Tensor mean_i = torch::empty({5, 8});
  torch::Tensor stddev_i = torch::empty({5, 8});

  torch::Tensor mean = torch::empty({8});
  torch::Tensor stddev = torch::empty({8});

  // Norm data tensor creation
  std::vector<torch::jit::IValue> normalized_input;
  torch::Tensor normalized_data = torch::empty_like(inputs);

  // Stats assessment
  for (int t = 0; t < inputs.size(1); ++t) {
    for (int f = 0; f < inputs.size(2); ++f) {
      torch::Tensor timestep_data = inputs.index({torch::indexing::Slice(), t, f});

      // Mean and standard deviation calculation (along axis 0)
      torch::Tensor mean_tt = timestep_data.mean(0);
      torch::Tensor stddev_tt = timestep_data.std(0);

      mean_i.index({t, f}) = mean_tt;
      stddev_i.index({t, f}) = stddev_tt;

      // Iter over all points
      for (int i = 0; i < inputs.size(0); ++i) {
        // Norm procedure: (data_timestep - mean) / stddev
        normalized_data.index({i, t, f}) = (timestep_data[i] - mean_i.index({t, f})) / stddev_i.index({t, f});
      }
    }
  }

  torch::jit::script::Module module;
  // Deserialize the ScriptModule from a file using torch::jit::load().
  module = torch::jit::load("/home/cenvinzf@coria.fr/workdir/full_coupling/case1/ANNpredict/model.pt");

  // Execute the model and turn its output into a tensor.
  normalized_input.push_back(normalized_data);
  at::Tensor outputs = module.forward(normalized_input).toTensor();

  // Stats collection
  for (int f = 0; f < inputs.size(2); ++f) {
    mean[f] = mean_i.index({torch::indexing::Slice(), f}).mean(0);
    stddev[f] = stddev_i.index({torch::indexing::Slice(), f}).mean(0);

    // Denormalization step
    for (int i = 0; i < inputs.size(0); ++i) {
      outputs.index({i, f}) = (outputs.index({i, f}) * stddev[f]) + mean[f];
    }
  }

  // Conversion to C++ array
  float** outputANN;
  float* data_ptr = outputs.data_ptr<float>();
  // Copiare i dati dal tensore PyTorch all'array C++
  for (int i = 0; i < 81897; ++i) {
    for (int k = 0; k < 8; ++k) {
        outputANN[i][k] = data_ptr[i * 8 + k];
    }
  }

  return outputANN;
 }
}

int main () {
  return 0;
}